#
# spec file for package wingpanel-indicator-power
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.desktop.wingpanel.power
Name:           wingpanel-indicator-power
Version:        8.0.2
Release:        1.1
Summary:        Wingpanel Power Indicator
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/wingpanel-indicator-power
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(wingpanel)

%description
A power indicator for Wingpanel.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}/locale
%find_lang power-indicator

%files
%license COPYING
%doc README.md
%dir %{_libdir}/wingpanel
%{_libdir}/wingpanel/libpower.so
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/io.elementary.wingpanel.power.metainfo.xml

%files lang -f power-indicator.lang

%changelog
* Thu Feb 13 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.2:
  * Update dependency in readme
  * Show the device model if available
  * Optimize Battery Icon Calculation and State Handling
  * Update translations
- update to 8.0.1:
  * Fix meson deprecations
  * Add more symbolic battery icons
  * Device: handle coarse battery level
* Thu Aug 22 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Drop inaccurate "Apps using lots of power" feature
  * Updated translations
- update to 6.2.1:
  * Updated translations
- update to 6.2.0:
  * Scroll horizontally on the panel icon to change display brightness
  * Do a better job hiding the brightness slider on unsupported displays
  * Updated translations
- update to 6.1.0:
  * Show brightness level when scrolled
  * Show battery percentage automatically at 20%% or lower
  * Match scroll direction with Sound indicator
  * Show "Fully Charged" at 100%% when plugged in
  * Updated translations
- update to 6.0.0:
  * Show battery statistics when selected
  * Launch apps using power when selected
  * Control display brightness by scrolling the indicator
  * Improvements for desktops with peripherals
  * Filter out internal devices
  * Show tooltip on hover
  * Performance improvements
  * Updated translations
- update to 2.2.0:
  * Support for Controllers and Pens
  * Reduce spacing when percentage is shown
  * Updated translations
- update to 2.1.5:
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.4:
  * DeviceList: Subclass ListBox (#107)
  * ScreenBrightness: misc cleanup (#104)
  * Merge branch 'origin/master' into Weblate
  * Indicator: GObject-style (#103)
  * PopoverWidget: Rewrite as Gtk.Grid with revealers (#102)
  * PopoverWidget: Place percent switch in a revealer and bind
    (#101)
  * PopoverWidget: simplify open settings (#100)
  * Remove the Utils file (#99)
  * Create DeviceRow.vala (#98)
  * Meson: Use GLib preset for l10n
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.3:
  * Remove warnings at startup and simplify the DisplayWidget
    (#89)
  * Use GLib.Settings instead of Granite.Settings (#87)
  * Simplify setting the backlight icon (#84)
  * Update brightness slider when brightness changes (#79)
  * Check brightness slider for null (#81)
  * Add support for tablets (and some other devices) (#78)
* Tue Jul  3 2018 avvissu@yandex.by
- Update to 2.1.2:
  * RDNN gschema
  * Remove unused gettext domain from gschema
  * Remove CMake (#75)
  * Merge remote-tracking branch 'origin/master'
  * Add Meson (#62)
  * Update visibility in display widget (#71)
  * Fix warnings about IOError (#70)
  * Update DBus name for brightness slider (#66)
  * Fix #13 Muti Battery by using the Upower display device for
    the panel (#64)
  * Use Gtk.ModelButton instead of Wingpanel button (#63)
  * Fix brightness mouse scrolling increment (#52)
  * Toggle percentage with middle click (#53)
  * Update indicator when batteries are added or removed (#50)
  * open power plug using settings URL (#51)
  * remove extra separator if there's no brightness slider (#49)
  * Add screenshot (#42)
  * Create .gitignore (#47)
  * Create CODE_OF_CONDUCT.md (#45)
* Sat Jun  9 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Add README files
- Remove obsolete macros
- Spec file cleanup
* Fri Jun  9 2017 mailaender@opensuse.org
- Add COPYING license file
* Tue May 16 2017 avvissu@yandex.by
- Update to 2.1.1:
  * Center with respect to other widgets in the panel (#32)
  * Update FSF Address (#29)
  * Match sound indicator's alignment and spacing (#25)
  * AppList.vala: adjust spacing and alignment (#27)
  * Reassign copyright from Wingpanel Developers to elementary
  * Add Travis CI (#24)
  * Only update brightness if it's changed (#22)
  * Make sure we hexpand the app list separator (#19)
  * Create README.md (#18)
  * Add a display brightness slider
  * Launchpad automatic translations update.
  * unmark COPYING file as executable
  * Indicator.vala: use new DisplayWidget properties
  * AppList.vala: Use Gtk.Grid instead of Gtk.Box
  * DeviceList.vala: Group all Grid.Attach methods
  * DisplayWidget.vala:
  * Use Gtk.Grid instead of Gtk.Box, and fix alignment due to
    this change
  * Use public properties instead of set methods
  * Group percent_revealer properties and methods
  * Group add methods
  * Use GObject-style construction for the widgets
  * Update license headers
  * Use the -charged icon when at 100%% and charging
* Tue Nov  1 2016 avvissu@yandex.by
- Update to 2.0.1:
  * Use GLib.AppInfo.launch instead of Granite SimpleComand
    (lp:1575376)
  * Launchpad automatic translations update.
* Mon Sep 19 2016 avvissu@yandex.by
- Update to 2.0
- Add glib2_gsettings_schema_requires macro
- Change target_link_libraries
- Spec file cleanup
* Wed Oct 21 2015 and.november@opensuse.org
- initial package (version 0.1) for openSUSE
